@@ -25,6 +25,7 @@ use crate::num::NumTuple;
 use crate::num::ToRounded;
 
 use crate::geom::Point;
+use crate::geom::Rect;
 
 mod size_iterator;
 pub use self::size_iterator::SizeIterator;
@@ -99,6 +100,10 @@ impl<N: Num> Size<N> {
         Point(self.width(), self.height())
     }
 
+    pub fn to_rect(self) -> Rect<N> {
+        Rect(Point::new_zero_value(), self)
+    }
+
     pub fn get_scale_diff(self, other: Self) -> Self {
         Size(other.width() / self.width(), other.height() / self.height())
     }
@@ -397,6 +402,17 @@ impl<N: Num> IntoIterator for Size<N> {
     }
 }
 
+#[cfg(test)]
+mod to_rect {
+    use super::*;
+
+    #[test]
+    fn it_should_return_rect_with_this_size() {
+        let size: Size<i32> = Size(123, 456);
+        assert_eq!(size.to_rect(), Rect(Point(0, 0), Size(123, 456)));
+    }
+}
+
 #[cfg(test)]
 mod longest_side {
     use super::*;
